intelmq.bots.experts.uwhoisd package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.experts.uwhoisd package

## Submodules

## intelmq.bots.experts.uwhoisd.expert module

`intelmq.bots.experts.uwhoisd.expert.` `BOT`

  alias of `intelmq.bots.experts.uwhoisd.expert.UniversalWhoisExpertBot`

class `intelmq.bots.experts.uwhoisd.expert.` `UniversalWhoisExpertBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  Universal Whois expert bot get the whois entry related an a domain, hostname, IP address, or ASN from a centralised uWhoisd instance

  `port`: int = 4243
  `process`()
  `server`: str = 'localhost'

## Module contents